@@ -1,4 +1,4 @@
-require "set"
+require "set" unless defined?(Set)
 require "molinillo"
 require "molinillo/modules/specification_provider"
 require_relative "solver/serializer"
@@ -11,7 +11,7 @@ module Solve
       #
       # @return [Integer]
       def timeout
-        seconds = 30 unless seconds = ENV["SOLVE_TIMEOUT"]
+        seconds = 30 unless ( seconds = ENV["SOLVE_TIMEOUT"] )
         seconds.to_i * 1_000
       end
 
@@ -171,8 +171,10 @@ module Solve
     def requirement_satisfied_by?(requirement, activated, spec)
       version = spec.version
       return false unless requirement.constraint.satisfies?(version)
+
       shared_possibility_versions = possibility_versions(requirement, activated)
       return false if !shared_possibility_versions.empty? && !shared_possibility_versions.include?(version)
+
       true
     end
 
@@ -261,7 +263,7 @@ module Solve
     end
 
     def build_sorted_solution(unsorted_solution)
-      nodes = Hash.new
+      nodes = {}
       unsorted_solution.each do |name, version|
         nodes[name] = @graph.artifact(name, version).dependencies.map(&:name)
       end
