@@ -1,5 +1,5 @@
-require "json"
-require "solve/graph"
+require "json" unless defined?(JSON)
+require_relative "../graph"
 
 module Solve
 
