@@ -152,9 +152,9 @@ describe "Solutions when using the ruby solver" do
 
     demands = [["bottom", "1.0.0"], ["middle", "1.0.0"]]
 
-    expect { Solve.it!(graph, demands, { :sorted => true } ) }.to raise_error { |error|
+    expect { Solve.it!(graph, demands, { sorted: true } ) }.to raise_error do |error|
       error.should be_a(Solve::Errors::NoSolutionError)
-    }
+    end
   end
 
   it "gives an empty solution when there are no demands" do
@@ -257,7 +257,7 @@ describe "Solutions when using the ruby solver" do
 
         demands = [["A"]]
 
-        result = Solve.it!(graph, demands, { :sorted => true })
+        result = Solve.it!(graph, demands, { sorted: true })
 
         result.should eql([
           ["C", "1.0.0"],
@@ -279,7 +279,7 @@ describe "Solutions when using the ruby solver" do
 
         demands = [["A"], ["B"]]
 
-        result = Solve.it!(graph, demands, { :sorted => true } )
+        result = Solve.it!(graph, demands, { sorted: true } )
 
         result.should eql([
           ["C", "1.0.0"],
@@ -299,7 +299,7 @@ describe "Solutions when using the ruby solver" do
 
         demands = [["A"]]
 
-        expect { Solve.it!(graph, demands, { :sorted => true } ) }.to raise_error(Solve::Errors::NoSolutionError)
+        expect { Solve.it!(graph, demands, { sorted: true } ) }.to raise_error(Solve::Errors::NoSolutionError)
       end
     end
   end
